summaryrefslogtreecommitdiff
path: root/tests
diff options
context:
space:
mode:
authorRobert Löhning <robert.loehning@qt.io>2022-06-22 15:59:18 +0200
committerRobert Löhning <robert.loehning@qt.io>2022-06-28 10:13:34 +0000
commit0c2e1cf0946376e4e433505a99177647430010e7 (patch)
treeba8699dc2259d772c2c143e7ce30ea6183594cf7 /tests
parentc1c255059e9b17dd5ccae806795a71af6d563145 (diff)
downloadqt-creator-0c2e1cf0946376e4e433505a99177647430010e7.tar.gz
Squish: Update location of Options dialog
Change-Id: Ie9df4f897621520744998c3dbd9a3c44600ba844 Reviewed-by: Christian Stenger <christian.stenger@qt.io>
Diffstat (limited to 'tests')
-rw-r--r--tests/system/shared/clang.py2
-rw-r--r--tests/system/shared/suites_qtta.py2
-rw-r--r--tests/system/shared/utils.py14
-rw-r--r--tests/system/suite_HELP/tst_HELP02/test.py2
-rw-r--r--tests/system/suite_editors/tst_clean_whitespaces/test.py2
-rw-r--r--tests/system/suite_editors/tst_generic_highlighter/test.py4
-rw-r--r--tests/system/suite_general/tst_default_settings/test.py2
-rw-r--r--tests/system/suite_general/tst_installed_languages/test.py2
-rw-r--r--tests/system/suite_general/tst_save_before_build/test.py2
9 files changed, 16 insertions, 16 deletions
diff --git a/tests/system/shared/clang.py b/tests/system/shared/clang.py
index cccafa8a20..43976ab3ac 100644
--- a/tests/system/shared/clang.py
+++ b/tests/system/shared/clang.py
@@ -52,7 +52,7 @@ def startCreatorVerifyingClang(useClang):
return False
def __openCodeModelOptions__():
- invokeMenuItem("Tools", "Options...")
+ invokeMenuItem("Edit", "Preferences...")
mouseClick(waitForObjectItem(":Options_QListView", "C++"))
clickOnTab(":Options.qt_tabwidget_tabbar_QTabBar", "Code Model")
diff --git a/tests/system/shared/suites_qtta.py b/tests/system/shared/suites_qtta.py
index 64a31e6a9a..dc7424a59a 100644
--- a/tests/system/shared/suites_qtta.py
+++ b/tests/system/shared/suites_qtta.py
@@ -59,7 +59,7 @@ def checkSyntaxError(issuesView, expectedTextsArray, warnIfMoreIssues = True):
# change autocomplete options to manual
def changeAutocompleteToManual(toManual=True):
- invokeMenuItem("Tools", "Options...")
+ invokeMenuItem("Edit", "Preferences...")
mouseClick(waitForObjectItem(":Options_QListView", "Text Editor"))
clickOnTab(":Options.qt_tabwidget_tabbar_QTabBar", "Completion")
ensureChecked(waitForObject(":Behavior.Autocomplete common prefix_QCheckBox"), not toManual)
diff --git a/tests/system/suite_HELP/tst_HELP02/test.py b/tests/system/suite_HELP/tst_HELP02/test.py
index 921a1c701b..aee31c78e8 100644
--- a/tests/system/suite_HELP/tst_HELP02/test.py
+++ b/tests/system/suite_HELP/tst_HELP02/test.py
@@ -72,7 +72,7 @@ def _shortcutMatches_(shortcutEdit, expectedText):
def setKeyboardShortcutForAboutQtC():
- invokeMenuItem("Tools", "Options...")
+ invokeMenuItem("Edit", "Preferences...")
mouseClick(waitForObjectItem(":Options_QListView", "Environment"))
clickOnTab(":Options.qt_tabwidget_tabbar_QTabBar", "Keyboard")
filter = waitForObject("{container={title='Keyboard Shortcuts' type='QGroupBox' unnamed='1' "
diff --git a/tests/system/suite_editors/tst_clean_whitespaces/test.py b/tests/system/suite_editors/tst_clean_whitespaces/test.py
index bf6e83a6e2..7a6decacb6 100644
--- a/tests/system/suite_editors/tst_clean_whitespaces/test.py
+++ b/tests/system/suite_editors/tst_clean_whitespaces/test.py
@@ -131,7 +131,7 @@ def isIgnoredFile(fileName, ignoredFiles):
def ignoredFilesFromSettings():
- invokeMenuItem("Tools", "Options...")
+ invokeMenuItem("Edit", "Preferences...")
mouseClick(waitForObjectItem(":Options_QListView", "Text Editor"))
waitForObject("{container=':Options.qt_tabwidget_tabbar_QTabBar' type='TabItem' "
"text='Behavior'}")
diff --git a/tests/system/suite_editors/tst_generic_highlighter/test.py b/tests/system/suite_editors/tst_generic_highlighter/test.py
index e3975c787e..fc5808f692 100644
--- a/tests/system/suite_editors/tst_generic_highlighter/test.py
+++ b/tests/system/suite_editors/tst_generic_highlighter/test.py
@@ -52,7 +52,7 @@ def getOrModifyFilePatternsFor(mimeType, filter='', toBePresent=None):
toSuffixArray = lambda x : [pat.replace("*", "") for pat in x.split(";")]
result = []
- invokeMenuItem("Tools", "Options...")
+ invokeMenuItem("Edit", "Preferences...")
mouseClick(waitForObjectItem(":Options_QListView", "Environment"))
waitForObject("{container=':Options.qt_tabwidget_tabbar_QTabBar' type='TabItem' "
"text='MIME Types'}")
@@ -115,7 +115,7 @@ def addHighlighterDefinition(*languages):
syntaxDirectory = __highlighterDefinitionsDirectory__()
toBeChecked = (os.path.join(syntaxDirectory, x + ".xml") for x in languages)
test.log("Updating highlighter definitions...")
- invokeMenuItem("Tools", "Options...")
+ invokeMenuItem("Edit", "Preferences...")
mouseClick(waitForObjectItem(":Options_QListView", "Text Editor"))
waitForObject("{container=':Options.qt_tabwidget_tabbar_QTabBar' type='TabItem' "
"text='Generic Highlighter'}")
diff --git a/tests/system/suite_general/tst_default_settings/test.py b/tests/system/suite_general/tst_default_settings/test.py
index 29c65425b0..bf0d55c689 100644
--- a/tests/system/suite_general/tst_default_settings/test.py
+++ b/tests/system/suite_general/tst_default_settings/test.py
@@ -35,7 +35,7 @@ def main():
appContext = startQC(['-settingspath', '"%s"' % emptySettings], False)
if not startedWithoutPluginError():
return
- invokeMenuItem("Tools", "Options...")
+ invokeMenuItem("Edit", "Preferences...")
__checkKits__()
clickButton(waitForObject(":Options.Cancel_QPushButton"))
invokeMenuItem("File", "Exit")
diff --git a/tests/system/suite_general/tst_installed_languages/test.py b/tests/system/suite_general/tst_installed_languages/test.py
index 237150a8a0..f2068b2a22 100644
--- a/tests/system/suite_general/tst_installed_languages/test.py
+++ b/tests/system/suite_general/tst_installed_languages/test.py
@@ -30,7 +30,7 @@ def main():
startQC()
if not startedWithoutPluginError():
return
- invokeMenuItem("Tools", "Options...")
+ invokeMenuItem("Edit", "Preferences...")
mouseClick(waitForObjectItem(":Options_QListView", "Environment"))
clickOnTab(":Options.qt_tabwidget_tabbar_QTabBar", "Interface")
languageName = testData.field(lang, "language")
diff --git a/tests/system/suite_general/tst_save_before_build/test.py b/tests/system/suite_general/tst_save_before_build/test.py
index 3befbbd8ea..74d0f685ae 100644
--- a/tests/system/suite_general/tst_save_before_build/test.py
+++ b/tests/system/suite_general/tst_save_before_build/test.py
@@ -27,7 +27,7 @@ source("../../shared/qtcreator.py")
def __openBuildAndRunSettings__():
- invokeMenuItem("Tools", "Options...")
+ invokeMenuItem("Edit", "Preferences...")
mouseClick(waitForObjectItem(":Options_QListView", "Build & Run"))
clickOnTab(":Options.qt_tabwidget_tabbar_QTabBar", "General")
diff --git a/tests/system/shared/utils.py b/tests/system/shared/utils.py
index 8c1e15e1c7..9a7332c6d1 100644
--- a/tests/system/shared/utils.py
+++ b/tests/system/shared/utils.py
@@ -180,7 +180,7 @@ def invokeMenuItem(menu, item, *subItems):
except:
nativeMouseClick(waitForObject(":Qt Creator_Core::Internal::MainWindow", 1000), 20, 20, 0, Qt.LeftButton)
# Use Locator for menu items which wouldn't work on macOS
- if menu == "Tools" and item == "Options..." or menu == "File" and item == "Exit":
+ if menu == "Edit" and item == "Preferences..." or menu == "File" and item == "Exit":
selectFromLocator("t %s" % item, item)
return
menuObject = waitForObjectItem(":Qt Creator.QtCreator.MenuBar_QMenuBar", menu)
@@ -269,7 +269,7 @@ def selectFromFileDialog(fileName, waitForFile=False, ignoreFinalSnooze=False):
# add Qt documentations from given paths
# param which a list/tuple of the paths to the qch files to be added
def addHelpDocumentation(which):
- invokeMenuItem("Tools", "Options...")
+ invokeMenuItem("Edit", "Preferences...")
mouseClick(waitForObjectItem(":Options_QListView", "Help"))
waitForObject("{container=':Options.qt_tabwidget_tabbar_QTabBar' type='TabItem' text='Documentation'}")
clickOnTab(":Options.qt_tabwidget_tabbar_QTabBar", "Documentation")
@@ -295,7 +295,7 @@ def addCurrentCreatorDocumentation():
if not os.path.exists(docPath):
test.fatal("Missing current Qt Creator documentation (expected in %s)" % docPath)
return
- invokeMenuItem("Tools", "Options...")
+ invokeMenuItem("Edit", "Preferences...")
mouseClick(waitForObjectItem(":Options_QListView", "Help"))
waitForObject("{container=':Options.qt_tabwidget_tabbar_QTabBar' type='TabItem' text='Documentation'}")
clickOnTab(":Options.qt_tabwidget_tabbar_QTabBar", "Documentation")
@@ -398,7 +398,7 @@ def regexVerify(text, expectedTexts):
# the function returns a list of the found Qt versions
def iterateQtVersions():
qtVersionNames = []
- invokeMenuItem("Tools", "Options...")
+ invokeMenuItem("Edit", "Preferences...")
mouseClick(waitForObjectItem(":Options_QListView", "Kits"))
clickOnTab(":Options.qt_tabwidget_tabbar_QTabBar", "Qt Versions")
treeView = waitForObject(":qtdirList_QTreeView")
@@ -417,7 +417,7 @@ def iterateQtVersions():
# param clickOkWhenDone set to True if the Options dialog should be closed by clicking the
# "OK" button. If False, the dialog will stay open
# param alreadyOnOptionsDialog set to True if you already have opened the Options Dialog
# (if False this function will open it via the MenuBar -> Tools -> Options...)
# param additionalFunction pass a function or name of a defined function to execute
# for each configured item on the list of Kits
# this function must take at least 2 parameters - the first is the full string
@@ -434,7 +434,7 @@ def iterateKits(clickOkWhenDone, alreadyOnOptionsDialog,
result = []
additionalResult = []
if not alreadyOnOptionsDialog:
- invokeMenuItem("Tools", "Options...")
+ invokeMenuItem("Edit", "Preferences...")
mouseClick(waitForObjectItem(":Options_QListView", "Kits"))
clickOnTab(":Options.qt_tabwidget_tabbar_QTabBar", "Kits")
treeView = waitForObject(":BuildAndRun_QTreeView")
@@ -470,7 +470,7 @@ class HelpViewer:
HELPMODE, SIDEBYSIDE, EXTERNALWINDOW = range(3)
def setFixedHelpViewer(helpViewer):
- invokeMenuItem("Tools", "Options...")
+ invokeMenuItem("Edit", "Preferences...")
mouseClick(waitForObjectItem(":Options_QListView", "Help"))
clickOnTab(":Options.qt_tabwidget_tabbar_QTabBar", "General")
mode = "Always Show "
@@ -417,7 +417,7 @@ def iterateQtVersions():
# "OK" button. If False, the dialog will stay open
# param alreadyOnOptionsDialog set to True if you already have opened the Options Dialog
-# (if False this function will open it via the MenuBar -> Tools -> Options...)
+# (if False this function will open it via the MenuBar -> Edit -> Preferences...)
# param additionalFunction pass a function or name of a defined function to execute
# for each configured item on the list of Kits